@@ -7,7 +7,7 @@ use POE qw(Filter::Line Filter::Stackable);
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Filter::IRCD;
 
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 sub new {
     my ($package, %self) = @_;
@@ -21,14 +21,20 @@ sub PCI_register {
     my ($self, $irc) = @_;
     
     if (!$irc->isa('POE::Component::IRC::State')) {
-        croak __PACKAGE__ . ' requires PoCo::IRC::State or a subclass thereof';
+        die __PACKAGE__ . " requires PoCo::IRC::State or a subclass thereof\n";
     }
     
-    if (!grep { $_->isa('App::Bondage::Recall') } @{ $irc->pipeline->{PIPELINE} }) {
-        croak __PACKAGE__ . ' requires App::Bondage::Recall';
+    if (!grep { $_->isa('App::Bondage::Recall') } values %{ $irc->plugin_list() } ) {
+        die __PACKAGE__ . " requires App::Bondage::Recall\n";
     }
     
-    $self->{filter} = POE::Filter::Stackable->new( Filters => [ POE::Filter::Line->new(), POE::Filter::IRCD->new() ] );
+    $self->{filter} = POE::Filter::Stackable->new(
+        Filters => [
+            POE::Filter::Line->new(),
+            POE::Filter::IRCD->new(),
+        ]
+    );
+    
     $self->{irc} = $irc;
     $irc->raw_events(1);
     $irc->plugin_register($self, 'SERVER', qw(raw));
@@ -38,18 +44,22 @@ sub PCI_register {
             $self => [ qw(_start _client_error _client_input) ],
         ],
     );
+
     return 1;
 }
 
 sub PCI_unregister {
     my ($self, $irc) = @_;
-    $self->_close_wheel();
+
+    $poe_kernel->call("$self", '_client_error');
     return 1;
 }
 
 sub _start {
-    my $self = $_[OBJECT];
-    
+    my ($kernel, $self) = @_[KERNEL, OBJECT];
+
+    $kernel->alias_set("$self");
+
     $self->{wheel} = POE::Wheel::ReadWrite->new(
         Handle       => $self->{Socket},
         InputFilter  => $self->{filter},
@@ -57,29 +67,36 @@ sub _start {
         InputEvent   => '_client_input',
         ErrorEvent   => '_client_error',
     );
+    delete $self->{Socket};
+    $self->{wheel_id} = $self->{wheel}->ID();
 
-    # send the user modes
-    if ($self->{irc}->umode()) {
-        $self->{wheel}->put(':' . $self->{irc}->server_name() . ' MODE ' . $self->{irc}->nick_name() . ' :+' . $self->{irc}->umode());
-    }
-    
-    my ($recall) = grep { $_->isa('App::Bondage::Recall') } @{ $self->{irc}->pipeline->{PIPELINE} };
-    $self->{wheel}->put($recall->recall());
+    my ($recall_plug) = grep { $_->isa('App::Bondage::Recall') } @{ $self->{irc}->pipeline->{PIPELINE} };
+    $self->{wheel}->put($recall_plug->recall());
     
     return;
 }
 
 sub _client_error {
-    my ($self, $id) = @_[OBJECT, ARG3];
-    #$self->{irc}->plugin_del($self) if defined $self->{wheel};
+    my ($kernel, $self) = @_[KERNEL, OBJECT];
+    my $irc = $self->{irc};
+    
+    if ($self->{wheel}) {
+        $self->{wheel}->put('ERROR :Closing link (Caught interrupt)');
+        $self->{wheel}->flush();
+        delete $self->{wheel};
+        $irc->send_event(irc_proxy_close => $self->{wheel_id});
+        $kernel->alias_remove("$self");
+        $irc->plugin_del($self) if grep { $_ == $self } values %{ $irc->plugin_list() };
+    }
     return;
 }
 
 sub _client_input {
     my ($self, $input) = @_[OBJECT, ARG0];
+    my $irc = $self->{irc};
     
     if ($input->{command} eq 'QUIT') {
-        $self->{irc}->plugin_del($self);
+        $irc->plugin_del($self);
         return;
     }
     elsif ($input->{command} eq 'PING') {
@@ -91,37 +108,31 @@ sub _client_input {
         if ($recipient =~ /^[#&+!]/) {
             # recreate channel messages from this client for
             # other clients to see
-            my $line = ':' . $self->{irc}->nick_long_form($self->{irc}->nick_name()) . " PRIVMSG $recipient :$msg";
+            my $line = ':' . $irc->nick_long_form($irc->nick_name()) . " PRIVMSG $recipient :$msg";
             
-            for my $client (grep { $_->isa('App::Bondage::Client') } @{ $self->{irc}->pipeline->{PIPELINE} } ) {
+            for my $client (grep { $_->isa('App::Bondage::Client') } @{ $irc->pipeline->{PIPELINE} } ) {
                 if ($client != $self) {
                     $client->put($line);
                 }
             }
         }
     }
-    $self->{irc}->yield(lc($input->{command}) => @{ $input->{params} });
     
-    return;
-}
-
-sub _close_wheel {
-    my $self = shift;
-    $self->{irc}->send_event('irc_proxy_close' => $self->{wheel}->ID());
-    delete $self->{wheel};
+    $irc->yield(quote => $input->{raw_line});
+    
     return;
 }
 
 sub S_raw {
     my ($self, $irc) = splice @_, 0, 2;
     my $raw_line = ${ $_[0] };
-    $self->{wheel}->put($raw_line);
+    $self->{wheel}->put($raw_line) if defined $self->{wheel};
     return PCI_EAT_NONE;
 }
 
 sub put {
     my ($self, $raw_line) = @_;
-    $self->{wheel}->put($raw_line);
+    $self->{wheel}->put($raw_line) if defined $self->{wheel};
     return;
 }
 
@@ -130,8 +141,7 @@ __END__
 
 =head1 NAME
 
-App::Bondage::Client - A PoCo-IRC plugin which
-handles a proxy client.
+App::Bondage::Client - A PoCo-IRC plugin which handles a proxy client.
 
 =head1 SYNOPSIS
 
@@ -147,11 +157,9 @@ It handles a input/output and disconnects from a proxy client.
 This plugin requires the IRC component to be L<POE::Component::IRC::State|POE::Component::IRC::State>
 or a subclass thereof.
 
-=head1 CONSTRUCTOR
+=head1 METHODS
 
-=over
-
-=item C<new>
+=head2 C<new>
 
 One argument:
 
@@ -160,13 +168,7 @@ One argument:
 Returns a plugin object suitable for feeding to L<POE::Component::IRC|POE::Component::IRC>'s
 C<plugin_add()> method.
 
-=back
-
-=head1 METHODS
-
-=over
-
-=item C<put>
+=head2 C<put>
 
 One argument:
 
@@ -174,8 +176,6 @@ An IRC protocol line
 
 Sends an IRC protocol line to the client
 
-=back
-
 =head1 AUTHOR
 
 Hinrik E<Ouml>rn SigurE<eth>sson, hinrik.sig@gmail.com
